<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(por omisión)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="224"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation>Uso: %1 [opciones] [soundfonts] [midifiles]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="227"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="229"/>
        <location filename="../qsynthOptions.cpp" line="285"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation>No crear un controlador de entrada MIDI [por omisión = sí]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="231"/>
        <location filename="../qsynthOptions.cpp" line="287"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation>El nombre del controlador MIDI que se va a utilizar [oss,alsa,alsa_seq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="233"/>
        <location filename="../qsynthOptions.cpp" line="289"/>
        <source>The number of midi channels [default = 16]</source>
        <translation>El número de canales MIDI [por omisión = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="235"/>
        <location filename="../qsynthOptions.cpp" line="291"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation>El controlador de audio [alsa,jack,oss,dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="237"/>
        <location filename="../qsynthOptions.cpp" line="293"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation>Intentar la conexión de las salidas de jack a puertos físicos</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="239"/>
        <location filename="../qsynthOptions.cpp" line="295"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation>El número de canales estereofónicos de audio [por omisión = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="241"/>
        <location filename="../qsynthOptions.cpp" line="297"/>
        <source>The number of audio groups [default = 1]</source>
        <translation>El número de grupos de audio [por omisión = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="243"/>
        <location filename="../qsynthOptions.cpp" line="299"/>
        <source>Size of each audio buffer</source>
        <translation>Tamaño de cada memoria intermedia de audio</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="245"/>
        <location filename="../qsynthOptions.cpp" line="301"/>
        <source>Number of audio buffers</source>
        <translation>Número de memorias intermedias de audio</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="247"/>
        <location filename="../qsynthOptions.cpp" line="303"/>
        <source>Set the sample rate</source>
        <translation>Establecer la frecuencia de muestreo</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="249"/>
        <location filename="../qsynthOptions.cpp" line="305"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Habilitar o deshabilitar la reverberación [1|0|yes|no|on|off, por omisión = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="251"/>
        <location filename="../qsynthOptions.cpp" line="307"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Habilitar o deshabilitar el efecto &quot;coro&quot; [1|0|yes|no|on|off, por omisión = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="253"/>
        <source>Set the master gain [0 &lt; gain &lt; 2, default = 1]</source>
        <translation>Establecer la ganancia de la salida principal [0 &lt; ganancia &lt; 2, por omisión = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="255"/>
        <location filename="../qsynthOptions.cpp" line="311"/>
        <source>Define a setting name=value</source>
        <translation>Definir un ajuste nombre=valor</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="257"/>
        <location filename="../qsynthOptions.cpp" line="313"/>
        <source>Create and start server [default = no]</source>
        <translation>Crear e iniciar el servidor [por omisión = no]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="259"/>
        <location filename="../qsynthOptions.cpp" line="315"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation>No leer mandatos desde el intérprete [ignorado]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="261"/>
        <location filename="../qsynthOptions.cpp" line="317"/>
        <source>Dump midi router events</source>
        <translation>Volcar eventos MIDI de encaminamiento</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="263"/>
        <location filename="../qsynthOptions.cpp" line="319"/>
        <source>Print out verbose messages about midi events</source>
        <translation>Imprimir mensajes detallados sobre eventos MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="265"/>
        <source>Show help about command line options</source>
        <translation>Mostrar ayuda sobre las opciones de línea de mandatos</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="267"/>
        <source>Show version information</source>
        <translation>Mostrar información de versión</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="309"/>
        <source>Set the master gain [0 &lt; gain &lt; 10, default = 1]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="323"/>
        <source>SoundFont Files</source>
        <translation>Archivos de soundfonts</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="324"/>
        <source>[soundfonts]</source>
        <translation>[soundfonts]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="326"/>
        <source>MIDI Files</source>
        <translation>Archivos MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="327"/>
        <source>[midifiles]</source>
        <translation>[midifiles]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="361"/>
        <location filename="../qsynthOptions.cpp" line="537"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation>La opción -m requiere un argumento (midi-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="371"/>
        <location filename="../qsynthOptions.cpp" line="546"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation>La opción -K requiere un argumento (midi-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="380"/>
        <location filename="../qsynthOptions.cpp" line="555"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation>La opción -a requiere un argumento (audio-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="394"/>
        <location filename="../qsynthOptions.cpp" line="567"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation>La opción -L requiere un argumento (audio-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="404"/>
        <location filename="../qsynthOptions.cpp" line="576"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation>La opción -G requiere un argumento (audio-groups).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="414"/>
        <location filename="../qsynthOptions.cpp" line="585"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation>La opción -z requiere un argumento (audio-bufsize).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="424"/>
        <location filename="../qsynthOptions.cpp" line="594"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation>La opción -c requiere un argumento (audio-bufcount).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="434"/>
        <location filename="../qsynthOptions.cpp" line="603"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation>La opción -r requiere un argumento (sample-rate).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="462"/>
        <location filename="../qsynthOptions.cpp" line="630"/>
        <source>Option -g requires an argument (gain).</source>
        <translation>La opción -g requiere un argumento (gain).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="471"/>
        <location filename="../qsynthOptions.cpp" line="639"/>
        <source>Option -o requires an argument.</source>
        <translation>La opción -o requiere un argumento.</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="506"/>
        <location filename="../qsynthOptions.cpp" line="688"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Opción desconocida &apos;%1&apos;.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="64"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="45"/>
        <source>Debugging option enabled.</source>
        <translation>Opción de depuración habilitada.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="48"/>
        <source>System tray disabled.</source>
        <translation>Bandeja del sistema deshabilitada.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="51"/>
        <source>Server option disabled.</source>
        <translation>Opción de servidor deshabilitada.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="54"/>
        <source>System reset option disabled.</source>
        <translation>Opción de reajuste del sistema deshabilitada.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="57"/>
        <source>Bank offset option disabled.</source>
        <translation>Opción de desplazamiento de bancos deshabilitada.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="72"/>
        <source>Using: Qt %1</source>
        <translation>Usando: Qt %1</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="78"/>
        <source>FluidSynth %1</source>
        <translation>FluidSynth %1</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="82"/>
        <source>Website</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="87"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Este programa es software libre; puede redistribuirlo y/o modificarlo</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="88"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>bajo los términos de la Licencia Pública General GNU  versión 2 o posterior.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="74"/>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="355"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="360"/>
        <source>Unset</source>
        <translation>Deponer</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="364"/>
        <source>Refresh</source>
        <translation>Refrescar</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="492"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="493"/>
        <source>Delete preset:</source>
        <translation>Borrar preajustes:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="495"/>
        <source>Are you sure?</source>
        <translation>¿Está seguro?</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="59"/>
        <source>Preset &amp;Name:</source>
        <translation>&amp;Nombre de los preajustes:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="80"/>
        <source>Settings preset name</source>
        <translation>Nombre de los preajustes</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="87"/>
        <source>(default)</source>
        <translation>(por omisión)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>Save settings as current preset name</source>
        <translation>Guardar ajustes con el nombre de preajustes actual</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="98"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>Delete current settings preset</source>
        <translation>Borrar el conjunto de ajustes actual</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="114"/>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="146"/>
        <source>Channels view</source>
        <translation>Vista de canales</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="171"/>
        <source>In</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="176"/>
        <source>Chan</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="181"/>
        <source>Bank</source>
        <translation>Banco</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="186"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="191"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="196"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="201"/>
        <source>Soundfont</source>
        <translation>Soundfont</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.cpp" line="863"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="907"/>
        <location filename="../qsynthMainForm.cpp" line="1617"/>
        <location filename="../qsynthMainForm.cpp" line="2366"/>
        <location filename="../qsynthMainForm.cpp" line="2396"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="909"/>
        <source>is about to terminate.</source>
        <translation>está a punto de terminar.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="910"/>
        <location filename="../qsynthMainForm.cpp" line="1620"/>
        <source>Are you sure?</source>
        <translation>¿Está seguro?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="865"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>El programa va a continuar en ejecución en la bandeja del sistema

Para terminar el programa, por favor elija &quot;Terminar&quot; 
en el menú contextual del icono de la bandeja del sistema.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="881"/>
        <source>Don&apos;t show this message again</source>
        <translation>No mostrar de nuevo este mensaje</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1018"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Cargando soundfont: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1029"/>
        <location filename="../qsynthMainForm.cpp" line="2056"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Ha fallado la carga del soundfont &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1056"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Reproduciendo archivo MIDI: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1063"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>Ha fallado la reproducción del archivo MIDI: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1268"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1376"/>
        <source>&amp;Hide</source>
        <translation>&amp;Ocultar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1372"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1377"/>
        <source>S&amp;how</source>
        <translation>&amp;Mostrar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1373"/>
        <source>Rest&amp;ore</source>
        <translation>Re&amp;staurar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1385"/>
        <location filename="../qsynthMainForm.cpp" line="1874"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Nuevo motor...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1387"/>
        <location filename="../qsynthMainForm.cpp" line="1876"/>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <location filename="../qsynthMainForm.cpp" line="1393"/>
        <location filename="../qsynthMainForm.cpp" line="1488"/>
        <source>Re&amp;start</source>
        <translation>Re&amp;iniciar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1393"/>
        <location filename="../qsynthMainForm.cpp" line="1490"/>
        <source>&amp;Start</source>
        <translation>&amp;Arrancar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <location filename="../qsynthMainForm.cpp" line="1395"/>
        <source>&amp;Reset</source>
        <translation>&amp;Reajustar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <location filename="../qsynthMainForm.cpp" line="1398"/>
        <source>&amp;Panic</source>
        <translation>&amp;Pánico</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <location filename="../qsynthMainForm.cpp" line="1402"/>
        <source>&amp;Channels</source>
        <translation>&amp;Canales</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <location filename="../qsynthMainForm.cpp" line="1407"/>
        <location filename="../qsynthMainForm.cpp" line="1880"/>
        <source>Set&amp;up...</source>
        <translation>C&amp;onfiguración...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1413"/>
        <source>Engines</source>
        <translation>Motores</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <location filename="../qsynthMainForm.cpp" line="1430"/>
        <source>&amp;Messages</source>
        <translation>M&amp;ensajes</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <location filename="../qsynthMainForm.cpp" line="1434"/>
        <source>&amp;Options...</source>
        <translation>O&amp;pciones...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <location filename="../qsynthMainForm.cpp" line="1440"/>
        <source>&amp;Quit</source>
        <translation>&amp;Terminar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="920"/>
        <source>Don&apos;t ask this again</source>
        <translation>No preguntar esto de nuevo</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1618"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Borrar motor fluidsynth:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2015"/>
        <source>Creating synthesizer engine</source>
        <translation>Creación del motor del sintetizador</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2019"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Ha fallado la creación del sintetizador

No es posible continuar.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2050"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Cargando el soundfont &quot;%1&quot; (desplazamiento de banco %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2063"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Ha fallado el desplazamiento de banco (%1) para el soundfont &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2073"/>
        <source>Creating audio driver (%1)</source>
        <translation>Creación del controlador de audio (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2087"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Ha fallado la creación del controlador de audio (%1)

No es posible continuar.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2100"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Creación del encaminador MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2109"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Ha fallado la creación del encaminador MIDI (%1)

No estará disponible la entrada MIDI.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2117"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Creación del controlador MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2126"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Ha fallado la creación del controlador MIDI (%1).

No estará disponible la entrada MIDI.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1045"/>
        <source>Creating MIDI player</source>
        <translation>Creación del reproductor MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1049"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Ha fallado la creación del reproductor MIDI.

Continuando sin un reproductor.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2135"/>
        <source>Creating server</source>
        <translation>Creación del servidor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2169"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Ha fallado la creación del servidor.

Continuando sin él.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2173"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Modo servidor deshabilitado.

Continuando sin él.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2207"/>
        <source>Synthesizer engine started.</source>
        <translation>Motor de sintetizador iniciado.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2250"/>
        <source>Destroying server</source>
        <translation>Destrucción del servidor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2258"/>
        <source>Stopping MIDI player</source>
        <translation>Deteniendo reproductor MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2260"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Esperando que el reproductor MIDI termine</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1039"/>
        <location filename="../qsynthMainForm.cpp" line="2262"/>
        <source>Destroying MIDI player</source>
        <translation>Destrucción del reproducción MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2270"/>
        <source>Destroying MIDI driver</source>
        <translation>Destrucción del controlador MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2274"/>
        <source>Destroying MIDI router</source>
        <translation>Destrucción del encaminador MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2281"/>
        <source>Destroying audio driver</source>
        <translation>Destrucción del controlador de audio</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2304"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Descargando el soundfont &quot;%1&quot; (SFID=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2308"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Ha fallado la descarga del soundfont: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2315"/>
        <source>Destroying synthesizer engine</source>
        <translation>Destruyendo el motor del sintetizador</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2319"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Motor del sintetizador terminado.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2367"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Los nuevos ajustes serán efectivas después
de reiniciar todos los motores de Fluidsynth.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2369"/>
        <location filename="../qsynthMainForm.cpp" line="2400"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Por favor, tenga en cuenta que esta operacón puede causar
trastornos temporales en MIDI y audio.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2371"/>
        <source>Do you want to restart all engines now?</source>
        <translation>¿Quiere reiniciar todos los motores ahora?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2397"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Los nuevos ajustes serán efectivos después
de reiniciar el motor de Fluidsynth:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2402"/>
        <source>Do you want to restart the engine now?</source>
        <translation>¿Quiere reiniciar el motor ahora?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1016"/>
        <source>Add a new engine</source>
        <translation>Añadir un nuevo motor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1029"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Selector de motor (clic con el botón derecho del ratón para menú)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1067"/>
        <source>Delete current engine</source>
        <translation>Borrar el motor actual</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="974"/>
        <source>Show/hide the channels view window</source>
        <translation>Mostrar/ocultar la ventana de vista de canales</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="127"/>
        <source>Complete engine restart</source>
        <translation>Reinicio completo del motor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="945"/>
        <source>Program reset (all channels)</source>
        <translation>Reajustar el programa (todos los canales)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="958"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Mostrar ajustes de la instancia y diálogo de configuración</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="46"/>
        <source>Master</source>
        <translation>Salida principal</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="64"/>
        <source>&amp;Gain</source>
        <translation>&amp;Ganancia</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="86"/>
        <location filename="../qsynthMainForm.ui" line="111"/>
        <source>Master Gain</source>
        <translation>Ganancia de la salida principal</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="932"/>
        <source>System reset</source>
        <translation>Reajuste del sistema</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="146"/>
        <source>Reverb</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="170"/>
        <source>Reverb effect activation</source>
        <translation>Activación del efecto de reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Ac&amp;tive</source>
        <translation>Ac&amp;tivar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="186"/>
        <location filename="../qsynthMainForm.ui" line="205"/>
        <source>Reverb Level</source>
        <translation>Nivel de reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="230"/>
        <source>&amp;Level</source>
        <translation>&amp;Nivel</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="252"/>
        <location filename="../qsynthMainForm.ui" line="293"/>
        <source>Reverb Width</source>
        <translation>Amplitud de reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="271"/>
        <source>&amp;Width</source>
        <translation>&amp;Amplitud</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="318"/>
        <location filename="../qsynthMainForm.ui" line="359"/>
        <source>Reverb Damp Factor</source>
        <translation>Factor de humedad de reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="337"/>
        <source>D&amp;amp</source>
        <translation>&amp;Humedad</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="384"/>
        <location filename="../qsynthMainForm.ui" line="425"/>
        <source>Reverb Room Size</source>
        <translation>Tamaño de sala de reverberación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="403"/>
        <source>R&amp;oom</source>
        <translation>&amp;Sala</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="453"/>
        <source>Chorus</source>
        <translation>Coro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="477"/>
        <source>Chorus Modulation Type</source>
        <translation>Tipo de modulación de coro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="481"/>
        <source>Sine</source>
        <translation>Seno</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="486"/>
        <source>Triangle</source>
        <translation>Triángulo</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="506"/>
        <source>T&amp;ype:</source>
        <translation>T&amp;ipo:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="534"/>
        <source>Chorus effect activation</source>
        <translation>Activación del efecto de coro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Act&amp;ive</source>
        <translation>Act&amp;ivar</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="550"/>
        <location filename="../qsynthMainForm.ui" line="597"/>
        <source>Number of Chorus Stages</source>
        <translation>Número de etapas de coro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="575"/>
        <source>&amp;N</source>
        <translation>&amp;N</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="616"/>
        <location filename="../qsynthMainForm.ui" line="663"/>
        <source>Chorus Level</source>
        <translation>Nivel de coro</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="641"/>
        <source>Le&amp;vel</source>
        <translation>Ni&amp;vel</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="682"/>
        <location filename="../qsynthMainForm.ui" line="735"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Velocidad de coro (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="710"/>
        <source>Chorus Speed Hz</source>
        <translation>Velocidad de coro Hz</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Spee&amp;d</source>
        <translation>Veloci&amp;dad</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="757"/>
        <location filename="../qsynthMainForm.ui" line="804"/>
        <source>Chorus Depth (ms)</source>
        <translation>Intensidad de coro (ms)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="782"/>
        <source>Dept&amp;h</source>
        <translation>&amp;Intensidad</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="829"/>
        <source>Output peak level</source>
        <translation>Nivel de pico de salida</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="847"/>
        <source>Quit this application</source>
        <translation>Terminar esta aplcación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="863"/>
        <source>Show general options dialog</source>
        <translation>Mostrar diálogo de opciones generales</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="879"/>
        <source>Show/hide the messages log window</source>
        <translation>Mostrar/ocultar la ventana de registro de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="898"/>
        <source>Show information about this application</source>
        <translation>Mostrar información sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>A&amp;bout...</source>
        <translation>A&amp;cerca de...</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="133"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Registro parado --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="143"/>
        <source>Logging started --- %1 ---</source>
        <translation>Registro iniciado --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="33"/>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="48"/>
        <source>Messages output log</source>
        <translation>Registro de salida de mensajes</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="315"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="316"/>
        <source>Some settings may be only effective
next time you start this application.</source>
        <translation>Algunas opciones pueden tener efecto solamente
después de la próxima vez que inicie esta aplicación.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="342"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="343"/>
        <source>Some options have been changed.</source>
        <translation>Algunas opciones han cambiado.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="344"/>
        <source>Do you want to apply the changes?</source>
        <translation>¿Quiere aplicar los cambios?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="501"/>
        <source>Messages Log</source>
        <translation>Registro de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="503"/>
        <source>Log files</source>
        <translation>Archivos de registro</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="461"/>
        <source>Display</source>
        <translation>Visualización</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="62"/>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="50"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="89"/>
        <source>Sample messages text font display</source>
        <translation>Texto de muestra para visualización de tipografía de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="117"/>
        <source>Select font for the messages text display</source>
        <translation>Seleccionar tipografía para la visualización de texto de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="120"/>
        <source>&amp;Font...</source>
        <translation>&amp;Tipografía...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="152"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Determina si se ha de conservar un máximo número de líneas en la ventana de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="155"/>
        <source>&amp;Messages limit:</source>
        <translation>Límite de &amp;mensajes:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="168"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>El máximo número de líneas de mensajes que se conservan en la vista</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="178"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="183"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="188"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="193"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="198"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="203"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="220"/>
        <source>Logging</source>
        <translation>Registro</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="241"/>
        <source>Messages log file</source>
        <translation>Archivo de registro de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="272"/>
        <source>Browse for the messages log file location</source>
        <translation>Explorar la ubicación del archivo de registro de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="275"/>
        <location filename="../qsynthOptionsForm.ui" line="694"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="288"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Determina si se ha de activar el registro de mensajes en un archivo.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="611"/>
        <source>Custom</source>
        <translation>Personalización</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="626"/>
        <source>&amp;Color palette theme:</source>
        <translation>Paleta de &amp;colores del tema:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="645"/>
        <source>Custom color palette theme</source>
        <translation>Paleta de colores personalizada</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="657"/>
        <source>Wonton Soup</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="662"/>
        <source>KXStudio</source>
        <translatorcomment>DO NOT TRANSLATE</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="691"/>
        <source>Manage custom color palette themes</source>
        <translation>Gestionar los temas personalizados de paleta de color</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="720"/>
        <source>&amp;Widget style theme:</source>
        <translation>Tema de estilo de &amp;widgets:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="736"/>
        <source>Custom widget style theme</source>
        <translation>Tema de estilo de widgets personalizado</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="307"/>
        <source>Other</source>
        <translation>Otros</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="322"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Determina si se ha de solicitar confirmación para terminar la aplicación</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="325"/>
        <source>&amp;Confirm application close</source>
        <translation>&amp;Confirmar el cierre de la aplicación</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="338"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Determina si se han de mantener todas las ventanas hijas por encima de la ventana principal</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="341"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>&amp;Mantener las ventanas hijas siempre encima</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="354"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Determina si se ha de capturar la salida estándar (stdout/stderr) en la ventana de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <source>Capture standard &amp;output</source>
        <translation>Capturar la salida &amp;estándard</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="370"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Determina si se han de monitorizar y mostrar los medidores de picos de salida del motor</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="373"/>
        <source>Output &amp;peak level meters</source>
        <translation>Medidores de &amp;picos de nivel de salida</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="399"/>
        <source>Whether to enable the system tray icon</source>
        <translation>Determina si se habilita el icono en la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="402"/>
        <source>&amp;Enable system tray icon</source>
        <translation>&amp;Habilitar el icono en la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="431"/>
        <source>Whether to start minimized to system tray</source>
        <translation>Determina si se inicia minimizado en la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="434"/>
        <source>Start minimi&amp;zed to system tray</source>
        <translation>Iniciar minimi&amp;zado en la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="473"/>
        <source>Knobs</source>
        <translation>Botones giratorios</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="504"/>
        <source>Graphic style for knobs</source>
        <translation>Estilo gráfico para los botones rotatorios</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="508"/>
        <source>Classic</source>
        <translation>Clásico</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="513"/>
        <source>Vokimon</source>
        <translation>Vokimon</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="518"/>
        <source>Peppino</source>
        <translation>Peppino</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="528"/>
        <location filename="../qsynthOptionsForm.ui" line="584"/>
        <source>Legacy</source>
        <translation>Heredado</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="589"/>
        <source>Radial</source>
        <translation>Radial</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="594"/>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="577"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Comportamiento del movimiento del ratón para los botones rotatorios</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="34"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="415"/>
        <source>Whether to show system tray message on main window close</source>
        <translation>Mostrar o no un mensaje en la bandeja del sistema al cerrar la ventana principal</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation>Mostra&amp;r mensaje en la bandeja del sistema al cerrar</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="775"/>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="760"/>
        <source>Defaults</source>
        <translation>Por omisión</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="819"/>
        <source>&amp;Base font size:</source>
        <translation>Tamaño &amp;base de fuentes:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="838"/>
        <source>Base application font size (pt.)</source>
        <translation>Tamaño base de fuentes de la aplicación (pt.)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="652"/>
        <location filename="../qsynthOptionsForm.ui" line="743"/>
        <location filename="../qsynthOptionsForm.ui" line="792"/>
        <location filename="../qsynthOptionsForm.ui" line="845"/>
        <location filename="../qsynthOptionsForm.cpp" line="44"/>
        <source>(default)</source>
        <translation>(por omisión)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="860"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="865"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="870"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="875"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="880"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="291"/>
        <source>Messages &amp;log file:</source>
        <translation>Archivo de &amp;registro de mensajes:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="488"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>Estilo gráfico de &amp;botones rotatorios:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="558"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Comportamiento del &amp;movimiento del ratón:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="850"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="855"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="523"/>
        <source>Skulpture</source>
        <translation>Skulpture</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm</name>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="40"/>
        <source>Color Themes</source>
        <translation>Temas de colores</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="46"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="64"/>
        <source>Current color palette name</source>
        <translation>Nombre actual de la paleta de colores</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="77"/>
        <source>Save current color palette name</source>
        <translation>Guardar el nombre actual de la paleta de colores</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="80"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="90"/>
        <source>Delete current color palette name</source>
        <translation>Borrar nombre actual de la paleta de colores</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="93"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="106"/>
        <source>Palette</source>
        <translation>Paleta</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="118"/>
        <source>Current color palette</source>
        <translation>Paleta de colores actual</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="128"/>
        <source>Generate:</source>
        <translation>Generar:</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="144"/>
        <source>Base color to generate palette</source>
        <translation>Color base para generar la paleta</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="151"/>
        <source>Reset all current palette colors</source>
        <translation>Restablecer todos los colores de la paleta actual</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="154"/>
        <source> Reset</source>
        <translation> Restablecer</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="177"/>
        <source>Import a custom color theme (palette) from file</source>
        <translation>Importar un tema personalizado de colores (paleta) desde un archivo</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="180"/>
        <source>Import...</source>
        <translation>Importar...</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="190"/>
        <source>Export a custom color theme (palette) to file</source>
        <translation>Exportar un tema personalizado de colores (paleta) a un archivo</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="193"/>
        <source>Export...</source>
        <translation>Exportar...</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.ui" line="216"/>
        <source>Show Details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="344"/>
        <source>Import File - %1</source>
        <translation>Importar archivo - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="260"/>
        <location filename="../qsynthPaletteForm.cpp" line="347"/>
        <location filename="../qsynthPaletteForm.cpp" line="392"/>
        <source>Palette files (*.%1)</source>
        <translation>Archivos de paletas (*.%1)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="258"/>
        <source>Save Palette - %1</source>
        <translation>Guardar paleta - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="261"/>
        <location filename="../qsynthPaletteForm.cpp" line="348"/>
        <location filename="../qsynthPaletteForm.cpp" line="393"/>
        <source>All files (*.*)</source>
        <translation>Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="379"/>
        <location filename="../qsynthPaletteForm.cpp" line="755"/>
        <location filename="../qsynthPaletteForm.cpp" line="763"/>
        <source>Warning - %1</source>
        <translation>Aviso - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="380"/>
        <source>Could not import from file:

%1

Sorry.</source>
        <translation>No se ha podido importar desde archivo: %1. Lo siento.</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="389"/>
        <source>Export File - %1</source>
        <translation>Exportar archivo - %1</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="756"/>
        <source>Some settings have been changed.

Do you want to discard the changes?</source>
        <translation>Algunas opciones han cambiado. ¿Desea descartar los cambios?</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="764"/>
        <source>Some settings have been changed:

&quot;%1&quot;.

Do you want to save the changes?</source>
        <translation>Algunas opciones han cambiado: &quot;%1&quot;. ¿Desea guardar los cambios?</translation>
    </message>
</context>
<context>
    <name>qsynthPaletteForm::PaletteModel</name>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1007"/>
        <source>Color Role</source>
        <translation>Rol de color</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1010"/>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1013"/>
        <source>Inactive</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <location filename="../qsynthPaletteForm.cpp" line="1016"/>
        <source>Disabled</source>
        <translation>Deshabilitado</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="145"/>
        <source>Channel %1</source>
        <translation>Canal %1</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Channel Preset</source>
        <translation>Preajuste de canal</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="65"/>
        <source>Preset</source>
        <translation>Preajuste</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="93"/>
        <source>Bank selector</source>
        <translation>Selector de canales</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Bank</source>
        <translation>Banco</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="124"/>
        <source>Program selector</source>
        <translation>Selector de programa</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="149"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="154"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="159"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="164"/>
        <source>Soundfont</source>
        <translation>Soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="173"/>
        <source>Whether to preview the current selection</source>
        <translation>Determina si se previsualizará la selección actual</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="176"/>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <location filename="../qsynthSetupForm.cpp" line="425"/>
        <source>Setup</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="702"/>
        <location filename="../qsynthSetupForm.cpp" line="986"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="703"/>
        <source>Some settings have been changed.</source>
        <translation>Algunos ajustes han cambiado.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="704"/>
        <source>Do you want to apply the changes?</source>
        <translation>¿Quiere aplicar los cambios?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="922"/>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="927"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="932"/>
        <source>Remove</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="937"/>
        <source>Move Up</source>
        <translation>Mover hacia arriba</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="941"/>
        <source>Move Down</source>
        <translation>Moves hacia abajo</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="966"/>
        <location filename="../qsynthSetupForm.cpp" line="967"/>
        <source>Soundfont files</source>
        <translation>Archivos de soundfonts</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="968"/>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="987"/>
        <source>Soundfont file already on list</source>
        <translation>Archivo de soundfont ya está en la lista</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="989"/>
        <source>Add anyway?</source>
        <translation>¿Añadir de todas formas?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="1016"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="1017"/>
        <source>Failed to add soundfont file</source>
        <translation>Ha fallado la adición del arhivo de soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="1019"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Por favor, verifique se trata de un soundfont válido.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="54"/>
        <source>Engine &amp;Name:</source>
        <translation>&amp;Nombre del motor:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="67"/>
        <source>Engine display name</source>
        <translation>Nombre visible de motor</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="96"/>
        <source>&amp;MIDI</source>
        <translation>&amp;MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="170"/>
        <location filename="../qsynthSetupForm.ui" line="725"/>
        <source>MIDI device name</source>
        <translation>nombre de dispositivo MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="125"/>
        <source>Input MIDI driver</source>
        <translation>Controlador de entrada MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="311"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>Identificador de cliente del secuenciador de ALSA</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="318"/>
        <source>pid</source>
        <translation>pid</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="323"/>
        <location filename="../qsynthSetupForm.ui" line="824"/>
        <source>qsynth</source>
        <translation>qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="366"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>Determina si se mostrarán eventos del encaminador MIDI en la ventana de mensajes</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="356"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Imprimir mensajes detallados sobre eventos MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="359"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>Mensajes &amp;detallados de eventos MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="202"/>
        <source>Number of MIDI channels</source>
        <translation>Número de canales MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="183"/>
        <source>MIDI &amp;Channels:</source>
        <translation>&amp;Canales MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="102"/>
        <source>Enable MIDI input</source>
        <translation>Habilitar entrada MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="105"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>Habilitar &amp;Entrada MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="251"/>
        <source>gm</source>
        <translation>gm</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="256"/>
        <source>gs</source>
        <translation>gs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="261"/>
        <source>mma</source>
        <translation>mma</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="266"/>
        <source>xs</source>
        <translation>xs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="231"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation>Modo de selección de &amp;Banco MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="244"/>
        <source>MIDI Bank Select mode</source>
        <translation>Modo de selección de Banco MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="377"/>
        <source>&amp;Audio</source>
        <translation>&amp;Audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="424"/>
        <source>Sample &amp;Format:</source>
        <translation>&amp;Formato de muestra:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="414"/>
        <source>Output audio driver</source>
        <translation>Controlador de salida de audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="112"/>
        <source>MIDI &amp;Driver:</source>
        <translation>&amp;Controlador MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="148"/>
        <source>MIDI D&amp;evice:</source>
        <translation>&amp;Dispositivo MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="298"/>
        <source>MIDI Client &amp;Name ID (ALSA/CoreMidi):</source>
        <translation>&amp;Nombre ID de Cliente MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="346"/>
        <source>Attempt to connect the MIDI inputs to the physical ports</source>
        <translation>Intentar conectar las entradas MIDI a los puertos físicos</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="349"/>
        <source>&amp;Auto Connect MIDI Inputs</source>
        <translation>&amp;Auto conectar entradas MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="369"/>
        <source>D&amp;ump MIDI router events</source>
        <translation>&amp;Volcado de eventos del enrutador MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="401"/>
        <source>Audio &amp;Driver:</source>
        <translation>Controlador de &amp;Audio:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="437"/>
        <source>Sample format</source>
        <translation>Formato de muestra</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="514"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Tamaño del periodo en bytes (tamaño de la memoria intermedia de audio)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="521"/>
        <location filename="../qsynthSetupForm.ui" line="609"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="526"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="531"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="536"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="541"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="546"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="551"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="556"/>
        <source>8192</source>
        <translation>8192</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="564"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>&amp;Número de memorias intermedias:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="463"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Frecuencia de muestreo en muestras por segundo (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="473"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="478"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="483"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="488"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="493"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="450"/>
        <source>Sample &amp;Rate:</source>
        <translation>F&amp;recuencia de muestreo:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="577"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Número de periodos (número de memorias intermedias de audio)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="584"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="589"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="594"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="599"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="604"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="501"/>
        <source>Buffer &amp;Size:</source>
        <translation>&amp;Tamaño de la memoria intermedia:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="643"/>
        <source>Audio &amp;Channels:</source>
        <translation>&amp;Canales de Audio:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="665"/>
        <source>Number of audio groups</source>
        <translation>Número de grupos de audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="684"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Número de voces polifónicas habilitadas</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="706"/>
        <source>Number of stereo audio channels</source>
        <translation>Número de canales estereofónicos de audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="738"/>
        <source>&amp;Polyphony:</source>
        <translation>&amp;Polifonía:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="770"/>
        <source>Audio &amp;Groups:</source>
        <translation>&amp;Grupos de Audio:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="809"/>
        <source>JACK client name identification</source>
        <translation>Identificación del nombre de cliente de JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="819"/>
        <source>fluidsynth</source>
        <translation>fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="847"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Intentar la conexión de las salidas de JACK a los puertos físicos</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="624"/>
        <source>Audio D&amp;evice:</source>
        <translation>D&amp;ispositivo de Audio:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="796"/>
        <source>JACK Client &amp;Name ID:</source>
        <translation>&amp;Nombre ID del cliente JACK:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="850"/>
        <source>&amp;Auto Connect JACK Outputs</source>
        <translation>&amp;Auto conexión de salidas JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="857"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Creación de múltiples puertos de salida de JACK para canales, grupos y efectos</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="860"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>&amp;Múltiples salidas de JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="883"/>
        <source>&amp;WASAPI Exclusive Mode</source>
        <translation>Modo exclusivo de &amp;WASAPI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="891"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Soundfonts</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="906"/>
        <source>Soundfont stack</source>
        <translation>Pila de soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="928"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="933"/>
        <location filename="../qsynthSetupForm.ui" line="1075"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="938"/>
        <source>Offset</source>
        <translation>Desplazamiento</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="951"/>
        <source>Open soundfont file for loading</source>
        <translation>Abrir archivo de soundfont para carga</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="954"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="964"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Editar desplazamiento del banco de soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="967"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edición</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="977"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Borrar el soundfont seleccionado de la pila</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="980"/>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1003"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Mover hacia arriba el soundfont seleccionado hacia la cima de la pila</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1006"/>
        <source>&amp;Up</source>
        <translation>A&amp;rriba</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1016"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Mover hacia abajo el soundfont seleccionado hacia la base de la pila</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1019"/>
        <source>&amp;Down</source>
        <translation>A&amp;bajo</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1032"/>
        <source>S&amp;ettings</source>
        <translation>A&amp;justes</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1080"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1085"/>
        <source>Realtime</source>
        <translation>Tiempo real</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1090"/>
        <source>Current</source>
        <translation>Actual</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1095"/>
        <source>Default</source>
        <translation>Por omisión</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1100"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1105"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1110"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
</context>
</TS>
